import { BigNumber, BigNumberish } from "@ethersproject/bignumber";
export interface IBaseToken {
    readonly name: string;
    readonly symbol: string;
    readonly addresses: {
        [k: number]: string;
    };
    readonly swapType: string;
    readonly hash: string;
    address: (chainId: number) => string | null;
    decimals: (chainId: number) => number | null;
}
export interface Token extends IBaseToken {
    isWrappedToken: boolean;
    underlyingToken?: Token;
    isEqual: (other: Token) => boolean;
    valueToWei: (amt: BigNumberish, chainId: number) => BigNumber;
    wrapperAddress: (chainId: number) => string | null;
}
export declare class BaseToken implements Token {
    readonly name: string;
    readonly symbol: string;
    readonly addresses: {
        [k: number]: string;
    };
    readonly swapType: string;
    readonly isETH: boolean;
    readonly hash: string;
    private readonly wrapperAddresses;
    protected readonly _decimals: {
        [k: number]: number;
    };
    constructor(args: {
        name: string;
        symbol: string;
        decimals: number | {
            [k: number]: number;
        };
        addresses: {
            [k: number]: string;
        };
        swapType: string;
        isETH?: boolean;
        wrapperAddresses?: {
            [k: number]: string;
        };
    });
    address(chainId: number): string | null;
    wrapperAddress(chainId: number): string | null;
    decimals(chainId: number): number | null;
    isEqual(other: Token): boolean;
    valueToWei(amt: BigNumberish, chainId: number): BigNumber;
    get isWrappedToken(): boolean;
}
export declare class WrappedToken extends BaseToken {
    readonly underlyingToken: BaseToken;
    constructor(args: {
        name: string;
        symbol: string;
        decimals: number | {
            [k: number]: number;
        };
        addresses: {
            [k: number]: string;
        };
        swapType: string;
        isETH?: boolean;
        underlyingToken: BaseToken;
        wrapperAddresses?: {
            [k: number]: string;
        };
    });
    get isWrappedToken(): boolean;
}
